@@ -1,3 +1,5 @@
+# -*- coding: utf-8 -*-
+
 import botocore
 import click
 import requests
@@ -9,7 +11,7 @@ from newrelic_lambda_cli.functions import get_function
 
 def index(region, runtime):
     req = requests.get(
-        "https://%s.nr-layers.iopipe.com/get-layers?CompatibleRuntime=%s"
+        "https://%s.layers.newrelic-external.com/get-layers?CompatibleRuntime=%s"
         % (region, runtime)
     )
     layers_response = req.json()
